(analog col theta sat bright)Returns new color of same type with its hue rotated and adjusted saturation & brightness.
Returns new color of same type with its hue rotated and adjusted saturation & brightness.
(closest-hue col)(closest-hue col hues)Takes a color and map of hues (e.g. thi.ng.color.core.primary-hues), returns key of closest hue.
Takes a color and map of hues (e.g. thi.ng.color.core.primary-hues), returns key of closest hue.
(cmyka [c m y k a])(cmyka c m y k)(cmyka c m y k a)(complementary col)Returns new color of same type with its hue rotated by 180 degrees.
Returns new color of same type with its hue rotated by 180 degrees.
(css col)(dist-hsv a b)Returns HSV distance of any two colors (in cartesian space).
Returns HSV distance of any two colors (in cartesian space).
(dist-rgb a b)Returns RGB distance of any two colors
Returns RGB distance of any two colors
(gamma-correct col gamma)Returns gamma corrected version of color as RGBA
Returns gamma corrected version of color as RGBA
(hex->int hex)(hsla [h s l a])(hsla h s l)(hsla h s l a)(hsva [h s v a])(hsva h s v)(hsva h s v a)(as-cmyka _)(magenta _)(black _)(hue _)(yellow _)(saturation _)(green _)(cyan _)(brightness _)(luminance _)(red _)(blue _)(alpha _)(adjust-luminance _ offset)Adjust lightness (per HSL) up or down, clamping result to 0.0-1.0
Adjust lightness (per HSL) up or down, clamping result to 0.0-1.0
(adjust-brightness _ offset)Adjust brightness (per HSV norms) up or down, clamping result to 0.0-1.0
Adjust brightness (per HSV norms) up or down, clamping result to 0.0-1.0
(rotate-hue _ theta)Rotate hue by radians.
Rotate hue by radians.
(adjust-saturation _ offset)Adjust saturation up or down, clamping result to 0.0-1.0
Adjust saturation up or down, clamping result to 0.0-1.0
(adjust-alpha _ offset)Adjust alpha up or down, clamping result to 0.0-1.0
Adjust alpha up or down, clamping result to 0.0-1.0
(as-css _)(as-hsla _)(as-hsva _)(as-int32 _)(as-int24 _)(int24 col)(int32 col)(int32 col alpha)(as-rgba _)(proxied-color-type to-rgba from-rgba)(random-analog col delta)(random-analog col theta sat bright)Returns new color of same type with its hue rotated and adjusted saturation & brightness within given tolerances (+/-).
Returns new color of same type with its hue rotated and adjusted saturation & brightness within given tolerances (+/-).
(random-rgb)Returns a random RGBA color with 100% alpha
Returns a random RGBA color with 100% alpha
(rgba [r g b a])(rgba r g b)(rgba r g b a)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |